@@ -23,11 +23,11 @@ Test::Aggregate - Aggregate C<*.t> tests to make them run faster.
 
 =head1 VERSION
 
-Version 0.363
+Version 0.364
 
 =cut
 
-our $VERSION = '0.363';
+our $VERSION = '0.364';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -359,7 +359,12 @@ sub run_this_test_program {
             local %SIG = %SIG;
             use warnings 'uninitialized';
             $builder->{'Test::Aggregate::Builder'}{file_for}{$package} = $test;
+            local $builder->{'Test::Aggregate::Builder'}{running} = $package;
             eval { $package->run_the_tests };
+            if ($@ && $@ == $Test::Aggregate::Builder::skip) {
+                $builder->skip( $builder->{'Test::Aggregate::Builder'}{skip_all}{$package} );
+                return;
+            }
             $@;
         }
     };
